@@ -11,16 +11,11 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Silly demo evolution module
+"""Silly demo evolution module."""
 
-$Id: evolve1.py 124134 2012-01-23 15:20:44Z menesis $
-"""
-__docformat__ = 'restructuredtext'
 
 generation = 1
 
-import zope.app.generations.demo
 
 def evolve(context):
     """Evolver 1"""
-    zope.app.generations.demo.evolve(context, generation)
