@@ -11,15 +11,12 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Silly demo evolution module
+"""Silly demo evolution module."""
+import zope.app.generations.demo
 
-$Id: evolve3.py 124134 2012-01-23 15:20:44Z menesis $
-"""
-__docformat__ = 'restructuredtext'
 
 generation = 3
 
-import zope.app.generations.demo
 
 def evolve(context):
     zope.app.generations.demo.evolve(context, generation)
