@@ -12,15 +12,14 @@
 #
 ##############################################################################
 """zope.app.generations common test related classes/functions/objects.
-
-$Id: testing.py 116575 2010-09-18 12:09:07Z icemac $
 """
 
 __docformat__ = "reStructuredText"
 
-import os
-from zope.app.testing.functional import ZCMLLayer
+from zope.app.wsgi.testlayer import BrowserLayer
 
-GenerationsLayer = ZCMLLayer(
-    os.path.join(os.path.split(__file__)[0], 'ftesting.zcml'),
-    __name__, 'GenerationsLayer', allow_teardown=True)
+import zope.app.generations
+
+
+GenerationsLayer = BrowserLayer(zope.app.generations,
+                                allowTearDown=True)
