@@ -13,9 +13,7 @@
 ##############################################################################
 """Utility functions for evolving database generations."""
 
-#BBB imports
-from zope.generations.utility import findObjectsMatching, findObjectsProviding
-try:
-    from zope.generations.utility import getRootFolder
-except ImportError:
-    pass
+# BBB imports
+from zope.generations.utility import findObjectsMatching
+from zope.generations.utility import findObjectsProviding
+from zope.generations.utility import getRootFolder
